@@ -1,32 +1,32 @@
 #' Check format of TDLM's inputs
 #'
-#' This function checks that the TDLM's inputs have the required format (an
-#' names).
+#' This function checks that the TDLM's inputs have the required format (and names).
 #'
-#' @param vectors a list of vectors. The list can contain one vector. It is
-#' recommended to name each element of the list. If `vectors = NULL` only the
+#' @param vectors A `list` of vectors. The list can contain one vector. It is
+#' recommended to name each element of the list. If `vectors = NULL`, only the
 #' matrices will be considered.
 #'
-#' @param matrices a list of matrices. The list can contain one matrix. It is
-#' recommended to name each element of the list. If `matrices = NULL` only the
+#' @param matrices A `list` of matrices. The list can contain one matrix. It is
+#' recommended to name each element of the list. If `matrices = NULL`, only the
 #' vectors will be considered (by default).
 #'
-#' @param check a character indicating what types of check
-#' ("format" or "format_and_names") should be used (see Details).
+#' @param check A `character` indicating which types of check
+#' (`"format"` or `"format_and_names"`) should be used (see Details).
+#' 
+#' @return
+#' A message indicating if the check has passed or failed.
 #'
-#' @details The `TDLM`'s inputs should be based on the same number of
+#' @details 
+#' The `TDLM`'s inputs should be based on the same number of
 #' locations sorted in the same order. `check = "format"` will run basic checks
 #' to ensure that the structure of the inputs (dimensions, class, type...) is
 #' correct.
 #'
-#' It is recommended to use the location ID as vector names, matrix rownames and
-#' matrix colnames. Set `check  = "format_and_names"` to check the inputs'
-#' names. The checks are run successively, so run the function as many times as
-#' needed to get the message indicating that the inputs passed the check
-#' successfully.
-#'
-#' @return
-#' A message indicating if the check has passed or failed.
+#' It is recommended to use the location ID as `vector` `names`, `matrix` 
+#' `rownames`, and `matrix` `colnames`. Set `check  = "format_and_names"` to 
+#' check the inputs' names. The checks are run successively, so run the function
+#' as many times as needed to get the message indicating that the inputs passed 
+#' the check successfully.
 #'
 #' @author
 #' Maxime Lenormand (\email{maxime.lenormand@inrae.fr})
@@ -49,6 +49,7 @@
 check_format_names <- function(vectors,
                                matrices = NULL,
                                check = "format_and_names") {
+  
   # Controls
   if (is.null(vectors) & is.null(matrices)) {
     stop("At least one of the vectors or matrices argument should be non-null.",
@@ -61,7 +62,7 @@ check_format_names <- function(vectors,
       names(vectors) <- paste0("Vector ", seq_len(length(vectors)))
       message(paste0(
         "No names identified in the vectors list.\n",
-        "Names have been automatically assigned.\n"
+        "Names have been automatically assigned."
       ))
     }
   }
@@ -77,8 +78,9 @@ check_format_names <- function(vectors,
   }
   controls(args = check, type = "character")
   if (!(check %in% c("format", "format_and_names"))) {
-    stop("Please choose check among the followings values:
-format or format_and_names", call. = FALSE)
+    stop(paste0("Please choose check from the following:\n",
+                "format or format_and_names."),
+         call. = FALSE)
   }
 
   # Format
@@ -117,7 +119,7 @@ format or format_and_names", call. = FALSE)
     controls(
       args = NULL,
       matrices = matrices,
-      type = "matrices_gof"
+      type = "matrices_matrices"
     )
     controls(
       args = NULL,
